If no file argument is provided, and cry_demo() has been opened without
paired dp_demo(), the CIF parameters of already opened cry_demo() will be
used.
Interactive rotation, zooming, and panning of structures are possible using
the 3D graphics library rgl. When the drag originates near the window
edge (within 5%), perform a Z-axis rotation.
This function also performs powder diffraction simulation and saves the
results to a file in the working directory. Currently, it doesn't account
for atomic ionization and uses standard atomic scattering factors.